@@ -34,7 +34,7 @@ def parse_to_python_object(string):
             sert, src = match.groups()
             yield sert, src
 
-    quoted_regex = re.compile(r"^\"(.*?)\"\B([\w\\\" :.@-]*(?=\"))?(.*)", re.DOTALL)
+    quoted_regex = re.compile(r"^\"(.*?(?<!\\))\"(.*)", re.DOTALL)
     unquoted_regex = re.compile(r"^([\w.@#-]+)(.*)", re.DOTALL)
 
     def parse_string(src):
@@ -45,9 +45,7 @@ def parse_to_python_object(string):
             
         match = quoted_regex.match(src)
         if match is not None:
-            string, tail, src = match.groups()
-            if tail:
-                string += f'"{tail}'
+            string, src = match.groups()
             yield string, src.strip()
 
     def parse_word(word, value=None):
